package com.acburdine.copybook;

import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.DataInputStream;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.FileWriter;
import java.io.IOException;
import java.io.InputStreamReader;

public class FileHandling {
	
	public FileHandling(String path, int mode) {
		this.mode = mode;
		this.file = new File(path);
	}
	public boolean Exists() {
		return file.exists();
	}
	public void Open() {
		if (this.mode == FileHandling.READ)
			this.OpenReadMode();
		else if (this.mode == FileHandling.WRITE)
			this.OpenWriteMode();
		else if (this.mode == FileHandling.APPEND)
			this.OpenAppendMode();
		else if (this.mode == FileHandling.BINARY)
			this.OpenBinaryMode();
		this.opened = true;
	}
	public String ReadLine() {
		if(!this.opened)
			this.Open();
		try {
			return this.bReader.readLine();
		} 
		catch(IOException e) {
			e.printStackTrace();
		}
		return null;
	}
	public void WriteLine(String line) {
		if (!this.opened)
			this.Open();
		try {
			this.bWriter.write(line);
			this.bWriter.newLine();
		}
		catch(IOException e) {
			e.printStackTrace();
		}
	}
	public void Close() {
		if(this.mode == FileHandling.READ) {
			try {
				this.bReader.close();
				this.dInput.close();
				this.fInput.close();
			}
			catch(IOException e) {
				e.printStackTrace();
			}
		}
		else if (this.mode == FileHandling.WRITE)
			try {
				this.bWriter.close();
				this.fWriter.close();
			}
			catch(IOException e) {
				e.printStackTrace();
			}
		else if (this.mode == FileHandling.APPEND)
			try {
				this.bWriter.close();
				this.fWriter.close();
			}
			catch(IOException e) {
				e.printStackTrace();
			}
		else if (this.mode == FileHandling.BINARY)
			try {
				this.fInput.close();
			}
			catch(IOException e) {
				e.printStackTrace();
			}
		this.opened = false;
	}
	private void OpenReadMode() {
		if(!this.file.exists()) {
			try {
				this.file.createNewFile();
			}
			catch(IOException e) {
				e.printStackTrace();
			}
		}
		try {
			this.fInput = new FileInputStream(this.file);
			this.dInput = new DataInputStream(this.fInput);
			this.bReader = new BufferedReader(new InputStreamReader(this.dInput));
		}
		catch(FileNotFoundException e) {
			e.printStackTrace();
		}
	}
	private void OpenWriteMode() {
		if(!this.file.exists()) {
			try {
				this.file.createNewFile();
			}
			catch(IOException e) {
				e.printStackTrace();
			}
		}
		try {
			this.fWriter = new FileWriter(this.file, false);
			this.bWriter = new BufferedWriter(this.fWriter);
		}
		catch(IOException e) {
			e.printStackTrace();
		}
	}
	private void OpenAppendMode() {
		if(!this.file.exists()) {
			try {
				this.file.createNewFile();
			}
			catch(IOException e) {
				e.printStackTrace();
			}
		}
		try {
			this.fWriter = new FileWriter(this.file, true);
			this.bWriter = new BufferedWriter(this.fWriter);
		}
		catch(IOException e) {
			e.printStackTrace();
		}
	}
	private void OpenBinaryMode() {
		try {
			this.fInput = new FileInputStream(this.file);
		}
		catch(FileNotFoundException e) {
			e.printStackTrace();
		}
	}
	public void CopyFileTo(String filepath) {
		if(!this.opened)
			this.Open();
		File file2 = new File(filepath);
		try 
		{
			FileOutputStream fOutput = new FileOutputStream(file2);
			byte[] buffer = new byte[1024];
			int bytes = 0;
			while ( (bytes = fInput.read(buffer)) > 0)
			{
				fOutput.write(buffer, 0, bytes);
			}
			fOutput.close();
		} 
		catch (FileNotFoundException e) 
		{
			e.printStackTrace();
		} 
		catch (IOException e) 
		{
			
			e.printStackTrace();
		}
	}
	public static void ClearDirectory(String directoryPath)
	{
		if (!directoryPath.endsWith("/"))
		{
			directoryPath += "/";
		}
		File dir = new File(directoryPath);
		if (!dir.exists())
			return;
		String[] files = dir.list();
		File f = null;
		int i = 0;
		while (i < files.length)
		{
			f = new File(directoryPath + files[i]);
			f.delete();
			i++;
		}
	}
	
	private boolean opened = false;
	private FileWriter fWriter = null;
	private BufferedWriter bWriter = null;
	
	private FileInputStream fInput = null;
	private DataInputStream dInput = null;
	private BufferedReader bReader = null;

	private int mode = 0;
	private File file = null;
	
	public static int READ = 1;
	public static int WRITE = 2;
	public static int APPEND = 3;
	public static int BINARY = 4;
}
